@@ -22,7 +22,14 @@ class ImageClassification(object):
         results = []
         for _imgs in chunk_list(images):     
             with torch.no_grad():
-                predicts = self.model(torch.stack([self.transform(Image.open(x).convert('RGB')).to(self.device) for x in _imgs]))
+                temp = []
+                if x in _img:
+                    if type(x) == str:
+                        temp.append(self.transform(Image.open(x).convert('RGB')).to(self.device))
+                    else:
+                        temp.append(self.transform(x).to(self.device))
+                preicts = self.model(torch.stack(temp))
+                #predicts = self.model(torch.stack([self.transform(Image.open(x).convert('RGB')).to(self.device) for x in _imgs]))
                 predicts = torch.nn.functional.softmax(predicts).max(1)            
             results.extend([{"pred": self.labels[x], "score":y} for x,y in zip(predicts.indices.cpu().numpy().tolist(),predicts.values.cpu().numpy().tolist())])
         return results
